==> paragraphs_summary_token-2.0.3.tar.gz: paragraphs_summary_token/tests/src/Kernel/TextSummaryBuilderTest.php <==
<?php

namespace Drupal\Tests\paragraphs_summary_token\Kernel;

use Drupal\KernelTests\KernelTestBase;
use Drupal\language\Entity\ConfigurableLanguage;
use Drupal\node\Entity\Node;
use Drupal\paragraphs\Entity\Paragraph;
use Drupal\Tests\paragraphs\FunctionalJavascript\ParagraphsTestBaseTrait;
use Drupal\Tests\token\Functional\TokenTestTrait;

/**
 * Test the text summary builder service.
 *
 * @group paragraphs_summary_token
 */
class TextSummaryBuilderTest extends KernelTestBase {

  use TokenTestTrait;
  use ParagraphsTestBaseTrait;

  /**
   * The bundle info service.
   *
   * @var \Drupal\Core\Entity\EntityTypeBundleInfo
   */
  protected $bundleInfo;

  /**
   * The content translation manager.
   *
   * @var \Drupal\content_translation\ContentTranslationManagerInterface
   */
  protected $contentTranslationManager;

  /**
   * The language manager.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected $languageManager;

  /**
   * The node storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $nodeStorage;

  /**
   * The text summary builder.
   *
   * @var \Drupal\paragraphs_summary_token\Service\SummaryBuilder
   */
  protected $textSummaryBuilder;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'system',
    'field',
    'file',
    'text',
    'entity_reference_revisions',
    'node',
    'user',
    'token',
    'language',
    'content_translation',
    'paragraphs',
    'paragraphs_summary_token',
    'paragraphs_summary_token_test',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->installEntitySchema('node');
    $this->installEntitySchema('paragraph');
    $this->installEntitySchema('user');
    $this->installSchema('system', ['sequences']);
    $this->container->get('module_handler')->loadInclude('paragraphs', 'install');

    // Add text paragraph.
    $this->addParagraphsType('text');
    $this->addFieldtoParagraphType('text', 'field_body', 'text_long');
    $this->addParagraphedContentType('page');

    // Add container paragraph.
    $this->addParagraphsType('paragraphs_container');
    $this->addParagraphsField('paragraphs_container', 'paragraphs_container_paragraphs', 'paragraph');

    // Add a second language.
    ConfigurableLanguage::createFromLangcode('nl')->save();

    // Initialize services.
    $this->contentTranslationManager = $this->container->get('content_translation.manager');
    $this->bundleInfo = $this->container->get('entity_type.bundle.info');
    $this->nodeStorage = $this->container->get('entity_type.manager')->getStorage('node');
    $this->languageManager = $this->container->get('language_manager');
    $this->textSummaryBuilder = $this->container->get('paragraphs_summary_token.text_summary_builder');

    // Mark the node page and paragraphs as translatable.
    $this->contentTranslationManager->setEnabled('node', 'page', TRUE);
    $this->contentTranslationManager->setEnabled('paragraph', 'paragraphs_container', TRUE);
    $this->contentTranslationManager->setEnabled('paragraph', 'text', TRUE);
    $this->bundleInfo->clearCachedBundles();
    $this->bundleInfo->getAllBundleInfo();
  }

  /**
   * Test the text summary builder service with a single paragraph.
   */
  public function testSummaryBuilderWithOneParagraph() {
    $content = $this->getRandomGenerator()->paragraphs(300);
    $paragraph = Paragraph::create([
      'type' => 'text',
      'field_body' => '<p>' . $content . '</p>',
    ]);
    $paragraph->save();

    $node = Node::create([
      'type' => 'page',
      'title' => 'Paragraphs Test',
      'field_paragraphs' => [$paragraph],
    ]);
    $node->save();

    // Test the default length.
    $this->assertEquals(
      text_summary(strip_tags(trim($content)), NULL, 300),
      $this->textSummaryBuilder->build($node->get('field_paragraphs'))
    );

    // Test the service with a different length provided.
    $this->assertEquals(
      text_summary(strip_tags(trim($content)), NULL, 200),
      $this->textSummaryBuilder->build($node->get('field_paragraphs'), 200)
    );
  }

  /**
   * Test the text summary builder service with multiple paragraph.
   */
  public function testSummaryBuilderWithMultipleParagraphs() {
    $paragraph1 = Paragraph::create([
      'type' => 'text',
      'field_body' => '<p>Paragraph 1</p>',
    ]);
    $paragraph1->save();
    $paragraph2 = Paragraph::create([
      'type' => 'text',
      'field_body' => '<p>Paragraph 2</p>',
    ]);
    $paragraph2->save();
    $paragraph3 = Paragraph::create([
      'type' => 'text',
      'field_body' => '<p>Paragraph 3',
    ]);
    $paragraph3->save();

    // Add test content with paragraph container.
    $node = Node::create([
      'type' => 'page',
      'title' => 'Paragraphs Test',
      'field_paragraphs' => [$paragraph1, $paragraph2, $paragraph3],
    ]);
    $node->save();

    $this->assertEquals(
      'Paragraph 1',
      $this->textSummaryBuilder->build($node->get('field_paragraphs'))
    );
  }

  /**
   * Test the text summary builder service with nested paragraphs.
   */
  public function testParagraphSummaryTokenWithNestedParagraphs() {
    $text_paragraph_1 = Paragraph::create([
      'type' => 'text',
      'field_body' => '',
    ]);
    $text_paragraph_1->save();
    $text_paragraph_2 = Paragraph::create([
      'type' => 'text',
      'field_body' => '',
    ]);
    $text_paragraph_2->save();
    $text_paragraph_3 = Paragraph::create([
      'type' => 'text',
      'field_body' => '',
    ]);
    $text_paragraph_3->save();
    $text_paragraph_4 = Paragraph::create([
      'type' => 'text',
      'field_body' => '<p>Paragraph 4</p>',
    ]);
    $text_paragraph_3->save();
    $text_paragraph_5 = Paragraph::create([
      'type' => 'text',
      'field_body' => '<p>Paragraph 5</p>',
    ]);
    $text_paragraph_5->save();

    // Create container that contains the first two text paragraphs.
    $paragraph_1 = Paragraph::create([
      'type' => 'paragraphs_container',
      'paragraphs_container_paragraphs' => [
        $text_paragraph_1,
        $text_paragraph_2,
      ],
    ]);
    $paragraph_1->save();

    $paragraph_2 = Paragraph::create([
      'type' => 'paragraphs_container',
      'paragraphs_container_paragraphs' => [
        $text_paragraph_3,
        $text_paragraph_4,
      ],
    ]);
    $paragraph_2->save();

    $paragraph_3 = Paragraph::create([
      'type' => 'paragraphs_container',
      'paragraphs_container_paragraphs' => [
        $text_paragraph_5,
      ],
    ]);
    $paragraph_3->save();

    // Add test content with paragraph container.
    $node = Node::create([
      'type' => 'page',
      'title' => 'Paragraphs Test',
      'field_paragraphs' => [$paragraph_1, $paragraph_2, $paragraph_3],
    ]);
    $node->save();

    $this->assertEquals(
      'Paragraph 4',
      $this->textSummaryBuilder->build($node->get('field_paragraphs'))
    );
  }

}

==> paragraphs_summary_token-2.0.5.tar.gz: paragraphs_summary_token/tests/src/Kernel/TextSummaryBuilderTest.php <==
<?php

namespace Drupal\Tests\paragraphs_summary_token\Kernel;

use Drupal\KernelTests\KernelTestBase;
use Drupal\node\Entity\Node;
use Drupal\paragraphs\Entity\Paragraph;
use Drupal\Tests\paragraphs\FunctionalJavascript\ParagraphsTestBaseTrait;

/**
 * Test the text summary builder service.
 *
 * @group paragraphs_summary_token
 */
class TextSummaryBuilderTest extends KernelTestBase {

  use ParagraphsTestBaseTrait;

  /**
   * The text summary builder.
   *
   * @var \Drupal\paragraphs_summary_token\Service\SummaryBuilder
   */
  protected $textSummaryBuilder;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'system',
    'field',
    'file',
    'text',
    'filter',
    'entity_reference_revisions',
    'node',
    'user',
    'token',
    'language',
    'content_translation',
    'paragraphs',
    'paragraphs_summary_token',
    'paragraphs_summary_token_test',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->installEntitySchema('node');
    $this->installEntitySchema('paragraph');
    $this->installEntitySchema('user');
    $this->installSchema('system', ['sequences']);
    $this->installConfig(['paragraphs_summary_token_test']);
    $this->container->get('module_handler')->loadInclude('paragraphs', 'install');

    // Add text paragraph.
    $this->addParagraphsType('text');
    $this->addFieldtoParagraphType('text', 'field_body', 'text_long');
    $this->addParagraphedContentType('page');

    // Add container paragraph.
    $this->addParagraphsType('paragraphs_container');
    $this->addParagraphsField('paragraphs_container', 'paragraphs_container_paragraphs', 'paragraph');

    // Initialize services.
    $this->textSummaryBuilder = $this->container->get('paragraphs_summary_token.text_summary_builder');
  }

  /**
   * Test the text summary builder service with a single paragraph.
   */
  public function testSummaryBuilderWithOneParagraph() {
    $content = $this->getRandomGenerator()->paragraphs(300);
    $paragraph = Paragraph::create([
      'type' => 'text',
      // This invalid HTML is by purpose to test the summary with a filter
      // format.
      'field_body' => '<p>' . $content,
    ]);
    $paragraph->save();

    $node = Node::create([
      'type' => 'page',
      'title' => 'Paragraphs Test',
      'field_paragraphs' => [$paragraph],
    ]);
    $node->save();

    // Test the default length.
    $this->assertEquals(
      text_summary(strip_tags(trim($content)), NULL, 300),
      $this->textSummaryBuilder->build($node->get('field_paragraphs'))
    );

    // Test the service with a different length provided.
    $this->assertEquals(
      text_summary(strip_tags(trim($content)), NULL, 200),
      $this->textSummaryBuilder->build($node->get('field_paragraphs'), 200)
    );

    // Test the service with no length provided.
    $this->assertEquals(
      text_summary(strip_tags(trim($content))),
      $this->textSummaryBuilder->build($node->get('field_paragraphs'), NULL)
    );

    // Test the service with a filter.
    $this->assertEquals(
      text_summary(strip_tags(trim($content)), 'test_filter', 300),
      $this->textSummaryBuilder->build($node->get('field_paragraphs'), 300, 'test_filter')
    );

    // Test the service with an unexisting filter.
    $this->assertEquals(
      '',
      $this->textSummaryBuilder->build($node->get('field_paragraphs'), 300, 'unexisting_filter')
    );
  }

  /**
   * Test the text summary builder service with multiple paragraph.
   */
  public function testSummaryBuilderWithMultipleParagraphs() {
    $paragraph1 = Paragraph::create([
      'type' => 'text',
      'field_body' => '<p>Paragraph 1</p>',
    ]);
    $paragraph1->save();
    $paragraph2 = Paragraph::create([
      'type' => 'text',
      'field_body' => '<p>Paragraph 2</p>',
    ]);
    $paragraph2->save();
    $paragraph3 = Paragraph::create([
      'type' => 'text',
      'field_body' => '<p>Paragraph 3',
    ]);
    $paragraph3->save();

    // Add test content with paragraph container.
    $node = Node::create([
      'type' => 'page',
      'title' => 'Paragraphs Test',
      'field_paragraphs' => [$paragraph1, $paragraph2, $paragraph3],
    ]);
    $node->save();

    $this->assertEquals(
      'Paragraph 1',
      $this->textSummaryBuilder->build($node->get('field_paragraphs'))
    );
  }

  /**
   * Test the text summary builder service with nested paragraphs.
   */
  public function testParagraphSummaryTokenWithNestedParagraphs() {
    $text_paragraph_1 = Paragraph::create([
      'type' => 'text',
      'field_body' => '',
    ]);
    $text_paragraph_1->save();
    $text_paragraph_2 = Paragraph::create([
      'type' => 'text',
      'field_body' => '',
    ]);
    $text_paragraph_2->save();
    $text_paragraph_3 = Paragraph::create([
      'type' => 'text',
      'field_body' => '',
    ]);
    $text_paragraph_3->save();
    $text_paragraph_4 = Paragraph::create([
      'type' => 'text',
      'field_body' => '<p>Paragraph 4</p>',
    ]);
    $text_paragraph_3->save();
    $text_paragraph_5 = Paragraph::create([
      'type' => 'text',
      'field_body' => '<p>Paragraph 5</p>',
    ]);
    $text_paragraph_5->save();

    // Create container that contains the first two text paragraphs.
    $paragraph_1 = Paragraph::create([
      'type' => 'paragraphs_container',
      'paragraphs_container_paragraphs' => [
        $text_paragraph_1,
        $text_paragraph_2,
      ],
    ]);
    $paragraph_1->save();

    $paragraph_2 = Paragraph::create([
      'type' => 'paragraphs_container',
      'paragraphs_container_paragraphs' => [
        $text_paragraph_3,
        $text_paragraph_4,
      ],
    ]);
    $paragraph_2->save();

    $paragraph_3 = Paragraph::create([
      'type' => 'paragraphs_container',
      'paragraphs_container_paragraphs' => [
        $text_paragraph_5,
      ],
    ]);
    $paragraph_3->save();

    // Add test content with paragraph container.
    $node = Node::create([
      'type' => 'page',
      'title' => 'Paragraphs Test',
      'field_paragraphs' => [$paragraph_1, $paragraph_2, $paragraph_3],
    ]);
    $node->save();

    $this->assertEquals(
      'Paragraph 4',
      $this->textSummaryBuilder->build($node->get('field_paragraphs'))
    );
  }

}
